@@ -234,6 +234,9 @@ class Stack:
             return None
         return self.stack.pop()
 
+    def reverse(self):
+        return Stack(stack=list(reversed(self.stack)))
+
     def extend(self, lst):
         if isinstance(lst, list):
             for itm in lst:
