@@ -3,7 +3,7 @@ import sys
 from typing import Text
 
 from django.conf import settings
-from django.db import connection, OperationalError
+from django.db import connection
 
 from isc_common.common import uuid4
 from sheduler import make_shedurer_tasks
@@ -193,7 +193,18 @@ def create_insert_update_delete_function_of_table(
         logger.error(ex)
 
 
-def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, params=[], indexes=[], unique_indexes=[], primary_key=None, table_name=None, drop=True) -> None:
+def create_table(
+        fields_str=None,
+        sql_str=None,
+        temporary='',
+        on_commit=None,
+        params=[],
+        indexes=[],
+        unique_indexes=[],
+        primary_key=None,
+        table_name=None,
+        any_constraints=[],
+        drop=True) -> None:
     if table_name is None:
         raise Exception(f'Table must have name')
 
@@ -220,8 +231,8 @@ def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, pa
 
     unique_indexes_str = ''
     if isinstance(unique_indexes, list):
-        indexes = [f'''CREATE INDEX {table_name}_{index[0]}_idx ON {table_name} USING btree ("{index[0]}") WHERE ({index[1] if index[1] else "1=1"});''' for index in unique_indexes]
-        unique_indexes_str = ';'.join(indexes)
+        qt_fld = list(map(lambda x: f'"{x}"', unique_indexes[0:len(unique_indexes) - 1]))
+        unique_indexes_str = ';\n' + f'''CREATE UNIQUE INDEX {table_name}_{'_'.join(unique_indexes)}_idx ON {table_name} USING btree ({','.join(qt_fld)}) WHERE ("{unique_indexes[len(unique_indexes) - 1]}" is null);'''
 
     sql_txt = ''
     if drop:
@@ -237,6 +248,7 @@ def create_table(fields_str=None, sql_str=None, temporary='', on_commit=None, pa
         sql_txt += f'''CREATE {temporary} TABLE {table_name} as ({sql_str}); {on_commit_str};'''
 
     sql_txt += pk_str
+    sql_txt += ';\n'.join(any_constraints)
     sql_txt += indexes_str
     sql_txt += unique_indexes_str
 
