@@ -156,7 +156,8 @@ class DSRequest(RPCRequest):
             else:
                 res = self.json
 
-            res = dict((key, value) for (key, value) in res.items() if not key.startswith('_') and key not in excluded_keys)
+            # res = dict((key, value) for (key, value) in res.items() if not key.startswith('_')  and key not in excluded_keys)
+            res = dict((key, value) for (key, value) in res.items() if key not in excluded_keys)
         return res
 
     def get_data_wrapped(self, excluded_keys=['grid'], cls=Wrapper):
